﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AppinyaLib.Database; 
using AppinyaLib.Comunication;
using AppinyaLib.Api.Entities;
using AppinyaLib.Api;
/// <summary>
/// Aplicació de Gestió Castellera
/// </summary>
/// <copyright>
/// Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
/// </copyright>
/// <author>
/// Daniel Horta Vidal
/// </author>
namespace AppinyaLib.BS
{
    public static class CastellerBs
    {
         public static CastellersPublication GetAllCastellers(String date)
        {

            using (castellersEntities db = new castellersEntities())
            {
                DateTime dcastellers = db.ACTUALITZACIONS.Where(it => it.ID_TABLA == "CASTELLERS").Select(t => t).FirstOrDefault().DATA_MODIFICACIO;

                 List<CASTELLER> lst = null;
                if (date == null || date.Length == 0)
                    lst = (from cas in db.CASTELLER select cas).ToList(); /*where (cas.NOM + cas.COGNOMS).Contains(query) == true */
                else
                {
                    DateTime dateT = ApiFunctions.convertApiDateHour(date);
                    lst = (from cas in db.CASTELLER where cas.DATA_MODIFICACIO.CompareTo(dateT) > 0 select cas).ToList(); /*where (cas.NOM + cas.COGNOMS).Contains(query) == true */
                }
                return new CastellersPublication()
                {
                    Castellers = lst.Select<CASTELLER, Casteller>(x => x).ToList(),
                    Date = dcastellers
                };  
            }

        }
     
        public static List<Casteller> EnviaInvitacio(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                //CASTELLER_DELEGA peticio =  db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER1 == owner.ID_CASTELLER && del.ID_CASTELLER2 == acceptor.Id).Select(t => t).FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.ENVIAR.Where(t =>t.ID_CASTELLER2 == rebre.Id).Select(x => x).FirstOrDefault();
                if (peticio == null)
                {
                    peticio = new CASTELLER_DELEGA()
                    {
                        ID_CASTELLER1 = owner.ID_CASTELLER,
                        ID_CASTELLER2 = rebre.Id,
                        CONFIRM = false

                    };
                    db.CASTELLER_DELEGA.Add(peticio);
                    db.SaveChanges();
                }


            }
            return UsuariBs.getUserInfo(userName).Casteller.DelegacioPropia;

        }
        /*
           usr.Casteller.ConfirmPrecence = cas.ASSISTENCIA.Select<ASSISTENCIA, Assistencia>(x => x).ToList();
                     usr.Casteller.Delegate = cas.ENVIAR.Where(t => t.CONFIRM).Select<CASTELLER_DELEGA, Casteller>(x => x.REBRE).ToList();
                     usr.Casteller.Invitations = cas.REBRE.Where(t => t.CONFIRM == false).Select<CASTELLER_DELEGA, Casteller>(x => x.ENVIAR).ToList();
                     usr.Casteller.AccepInvitations = cas.REBRE.Where(t => t.CONFIRM).Select<CASTELLER_DELEGA, Casteller>(x => x.ENVIAR).ToList(); 
          */
        public static List<Casteller> AcceptarInvitacio(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                //CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER2 == owner.ID_CASTELLER && del.ID_CASTELLER1 == delegated.Id).Select(t => t).FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.REBRE.Where(t => t.ID_CASTELLER1 == rebre.Id && t.CONFIRM==false).Select(x => x).FirstOrDefault();
                if (peticio != null)
                {
                    peticio.CONFIRM = true;
                    peticio.DATA_ALTA = DateTime.Now;  
                    db.SaveChanges();
                }
                return UsuariBs.getUserInfo(userName).Casteller.Invitations;

            }  
        }
        
        public static List<Casteller> EsborrarInvitacio(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.REBRE.Where(t => t.ID_CASTELLER1 == rebre.Id && t.CONFIRM==false).Select(x => x).FirstOrDefault();
                //CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER1 == owner.ID_CASTELLER && del.ID_CASTELLER2 == delegated.Id).Select(t => t).FirstOrDefault();
                if (peticio != null)
                {
                    db.CASTELLER_DELEGA.Remove(peticio);
                    db.SaveChanges();
                }
                return UsuariBs.getUserInfo(userName).Casteller.Invitations;

            }
        }

        public static List<Casteller> EsborrarAcceptacio(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.REBRE.Where(t => t.ID_CASTELLER1 == rebre.Id && t.CONFIRM==true).Select(x => x).FirstOrDefault();
                //CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER1 == owner.ID_CASTELLER && del.ID_CASTELLER2 == delegated.Id).Select(t => t).FirstOrDefault();
                if (peticio != null)
                {
                    db.CASTELLER_DELEGA.Remove(peticio);
                    db.SaveChanges();
                }
                return UsuariBs.getUserInfo(userName).Casteller.AccepInvitations;

            }
        }

        public static List<Casteller> EsborrarDelegacioPropia(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.ENVIAR.Where(t => t.ID_CASTELLER2 == rebre.Id && t.CONFIRM==false).Select(x => x).FirstOrDefault();
                //CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER1 == owner.ID_CASTELLER && del.ID_CASTELLER2 == delegated.Id).Select(t => t).FirstOrDefault();
                if (peticio != null)
                {
                    db.CASTELLER_DELEGA.Remove(peticio);
                    db.SaveChanges();
                }
                return UsuariBs.getUserInfo(userName).Casteller.DelegacioPropia;

            }
        }
        public static List<Casteller> EsborrarAccepDelegacioPropia(Casteller rebre, String userName)
        {

            using (castellersEntities db = new castellersEntities())
            {
                CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
                CASTELLER_DELEGA peticio = owner.ENVIAR.Where(t => t.ID_CASTELLER2 == rebre.Id && t.CONFIRM==true).Select(x => x).FirstOrDefault();
                //CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER1 == owner.ID_CASTELLER && del.ID_CASTELLER2 == delegated.Id).Select(t => t).FirstOrDefault();
                if (peticio != null)
                {
                    db.CASTELLER_DELEGA.Remove(peticio);
                    db.SaveChanges();
                }
                return UsuariBs.getUserInfo(userName).Casteller.AccepDelegacioPropia;

            }
        }
        //public static List<Casteller> RemoveInvitation(Casteller sender, String userName)
        //{

        //    using (castellersEntities db = new castellersEntities())
        //    {
        //        CASTELLER owner = db.AspNetUsers.Where(it => it.UserName == userName).Select(t => t).First().CASTELLER.FirstOrDefault();
        //        CASTELLER_DELEGA peticio = db.CASTELLER_DELEGA.Where(del => del.ID_CASTELLER2 == owner.ID_CASTELLER && del.ID_CASTELLER1 == sender.Id).Select(t => t).FirstOrDefault();
        //        if (peticio != null)
        //        {
        //            db.CASTELLER_DELEGA.Remove(peticio);
        //            db.SaveChanges();
        //        }
        //        return UsuariBs.getUserInfo(userName).Casteller.Delegate;

        //    }
        //}

    }
}
