﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks; 
using AppinyaLib.Database;
using AppinyaLib.Comunication;
using AppinyaLib.Api.Entities;
/// <summary>
/// Aplicació de Gestió Castellera
/// </summary>
/// <copyright>
/// Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
/// </copyright>
/// <author>
/// Daniel Horta Vidal
/// </author>
namespace AppinyaLib.Segurity
{
    public class SegurityBs
    {
        /**
         * Confirmacion del correo , tiene una marca temporal que identifica en que momento se genero el token
         */ 
        public static Boolean ConfirmationEmail (String userName, String token )
        {
            using (castellersEntities db = new castellersEntities())
            {
                UserInfo user = (from users in db.AspNetUsers
                                 where users.UserName == userName
                                 select new UserInfo()
                                 {
                                     Id = users.Id,
                                     ConfirmEmail = users.EmailConfirmed,
                                     ConfirmCasteller = false,
                                     Email = users.Email,
                                     LastName = "",
                                     Name = "",
                                     PhoneNumber = users.PhoneNumber,
                                     Privilege = users.AspNetRoles.FirstOrDefault().Name
                                 }).FirstOrDefault();
                if (user == null) return false;
                if (user.ConfirmCasteller) return false;
                

                CONFIRMARCORREU_LOG log = db.CONFIRMARCORREU_LOG.Where(t => t.EMAIL == userName && t.ANULAT == false).FirstOrDefault();

                if (log != null && (log.TOKEN == token))
                {
                    log.ANULAT = true;
                    AspNetUsers aspUser = db.AspNetUsers.Where(t => t.Email == userName).FirstOrDefault();
                    if (DateTime.Compare(log.DATA, DateTime.Now.AddDays(1)) > 0)
                    {
                        db.SaveChanges(); 
                        return false;
                    }else
                    {
                        aspUser.EmailConfirmed = true;
                        db.SaveChanges();
                        return true;
                    }  
                }
                else
                    return false; 


            }


        }

        /*
         * Envia el Email de confirmacion del Correo del usuario, generea un token aleatorio i se envia por correo electronico
         */
        public static  void SendEmailConfirmation(String userName , String clientId, String urlBase,String urlTemplate)
        {
            if (userName == null) throw new ArgumentNullException("userName parametro Nulo ");
            if (urlBase == null) throw new ArgumentNullException("urlBase parametro Nulo ");
            if (clientId == null) throw new ArgumentNullException("urlBase parametro Nulo ");
            if (urlTemplate == null) throw new ArgumentNullException("urlBase parametro Nulo ");

            using (castellersEntities db = new castellersEntities())
            {
                UserInfo user = (from users in db.AspNetUsers
                        where users.UserName == userName
                        select new UserInfo()
                        {
                            Id = users.Id,
                            ConfirmEmail = users.EmailConfirmed,
                            ConfirmCasteller = false,
                            Email = users.Email,
                            LastName = "",
                            Name = "",
                            PhoneNumber = users.PhoneNumber,
                            Privilege = users.AspNetRoles.FirstOrDefault().Name
                        }).FirstOrDefault();
                if (user == null) return;
                if (user.ConfirmCasteller) return;
                Random random = new Random();
                const string chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
                String tokenG = new string(Enumerable.Repeat(chars, 64)
                  .Select(s => s[random.Next(s.Length)]).ToArray());

                List<CONFIRMARCORREU_LOG> logs = db.CONFIRMARCORREU_LOG.Where(t => t.EMAIL == userName && t.ANULAT==false).ToList();
                foreach(CONFIRMARCORREU_LOG log1 in logs)
                {
                    log1.ANULAT = true; 

                }
                CONFIRMARCORREU_LOG log = new CONFIRMARCORREU_LOG()
                {
                    CLIENTID = clientId,
                    TOKEN = tokenG,
                    EMAIL = userName
                    
                };
                db.CONFIRMARCORREU_LOG.Add(log);
                db.SaveChanges();
                Dictionary<String,String> parames = new Dictionary<String, String>();
                parames.Add("Url", urlBase + "/Api/User/mailConfirmation?token="+tokenG+ "&userName=" + userName);
                parames.Add("message", "Nota: Aquest correu només es valid durant 24 horas.");
                SendMail.SendEmailWithHtmlTemplate("Confirmació Email", userName, urlTemplate, parames);


            }
            

        }   
        /*
         * Devuelve la informacion del usuario  
         */
        public UserInfo GetUserInfo(String userName)
        {
            if (userName == null) throw new ArgumentNullException("userName parametro Nulo ");

            using (castellersEntities db = new castellersEntities())
            {
                return (from users in db.AspNetUsers
                        where users.UserName == userName
                        select new UserInfo()
                        {
                            Id = users.Id,
                            ConfirmEmail = users.EmailConfirmed,
                            ConfirmCasteller = false,
                            Email = users.Email,
                            LastName = "",
                            Name = "",
                            PhoneNumber = users.PhoneNumber,
                            Privilege = users.AspNetRoles.FirstOrDefault().Name
                        }).FirstOrDefault();
            }
        }

    }
}
