var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espa�a (CC BY-NC 3.0 ES)
**/
import { Component, ViewChild } from '@angular/core';
import { Events, MenuController, Nav, Platform, AlertController, ToastController, LoadingController } from 'ionic-angular';
import { Splashscreen } from 'ionic-native';
import { AccountPage } from '../pages/account/account';
import { LoginPage } from '../pages/login/login';
import { MapPage } from '../pages/map/map';
import { SignupPage } from '../pages/signup/signup';
import { TabsPage } from '../pages/tabs/tabs';
import { TutorialPage } from '../pages/tutorial/tutorial';
import { EsdevenimentListPage } from '../pages/esdeveniment-list/esdeveniment-list';
import { NoticiesListPage } from '../pages/noticies-list/noticies-list';
import { CastellerListPage } from '../pages/castellers-list/castellers-list';
import { SupportPage } from '../pages/support/support';
import { AssistenciaListPage } from '../pages/assistencia-list/assistencia-list';
import { StoreData } from '../providers/storage.data';
import { PublicacionsService } from "../providers/publicacions.service";
import { AuthenticateService } from "../providers/authenticate.service";
import { CastellersService } from "../providers/castellers.service";
var AppinyaApp = (function () {
    function AppinyaApp(events, menu, platform, storeData, authenticateService, publicacionsService, castellersService, alertCtrl, toastCtrl, loadingCtrl) {
        this.events = events;
        this.menu = menu;
        this.platform = platform;
        this.storeData = storeData;
        this.authenticateService = authenticateService;
        this.publicacionsService = publicacionsService;
        this.castellersService = castellersService;
        this.alertCtrl = alertCtrl;
        this.toastCtrl = toastCtrl;
        this.loadingCtrl = loadingCtrl;
        this.appPages = [
            { id: 1, title: 'Noticies', component: TabsPage, tabComponent: NoticiesListPage, index: 0, icon: 'paper', disabled: false },
            { id: 2, title: 'Calendari', component: TabsPage, tabComponent: EsdevenimentListPage, index: 1, icon: 'calendar', disabled: false },
            { id: 3, title: 'Map', component: MapPage, icon: 'map', disabled: false },
            { id: 4, title: 'Suport', component: SupportPage, icon: 'flask', disabled: false },
        ];
        this.loggedInPages = [
            { id: 5, title: 'Fitxa Personal', component: AccountPage, icon: 'person', disabled: false },
            { id: 6, title: 'Confirmats', component: AssistenciaListPage, icon: 'thumbs-up', disabled: true },
            { id: 7, title: 'Castellers', component: TabsPage, tabComponent: CastellerListPage, index: 2, icon: 'contacts', disabled: true }
        ];
        this.loggedOutPages = [
            { id: 8, title: 'Accedeix', component: LoginPage, icon: 'log-in', disabled: false },
            { id: 9, title: 'Suport', component: TabsPage, tabComponent: SupportPage, index: 3, icon: 'flask', disabled: false },
            { id: 10, title: 'Registre\'t!', component: SignupPage, icon: 'person-add', disabled: false }
        ];
        console.info("Cosntructor app.component");
        this.platformReady();
        this.rootPage = TabsPage;
        if (!this.storeData.getSessionToken())
            this.enableLoginMenu(true);
    }
    AppinyaApp.prototype.ngOnInit = function () {
        console.info("ngOnInit");
        // Load de las variables de la memoria permanente
        this.storeData.loadStore();
        // Activar los eventos de Login y de store
        this.listenEvents();
    };
    AppinyaApp.prototype.logout = function () {
        this.storeData.logout();
        this.nav.goToRoot(null);
        this.loadPublicacions();
    };
    AppinyaApp.prototype.openPage = function (page) {
        var _this = this;
        if (page.index) {
            this.nav.setRoot(page.component, { tabIndex: page.index });
        }
        else {
            this.nav.setRoot(page.component).catch(function () {
                console.error("Error en la navegacion no tiene un componente asignado en el Nav");
            });
        }
        if (page.logsOut === true) {
            setTimeout(function () {
                _this.storeData.logout();
            }, 1000);
        }
    };
    AppinyaApp.prototype.openTutorial = function () {
        this.nav.setRoot(TutorialPage);
    };
    /**
     * Subscripcion de eventos de la aplicacion todo centralizado en app.components
     */
    AppinyaApp.prototype.listenEvents = function () {
        var _this = this;
        // Evento de login
        this.events.subscribe('user:login', function () {
            _this.enableLoginMenu(false);
            // Cargar la informacion del usuario al mobil 
            if (_this.storeData.getSessionToken()) {
                _this.loadUserInfo();
            }
            else {
                _this.enableAnonimous();
                console.info("No hay toquen");
            }
        });
        this.events.subscribe('user:logout', function () {
            _this.enableAnonimous();
        });
        // Evento Cuando se carga la base de datos con los datos de trabajo se actualiza la informacion del usuario
        this.events.subscribe('store:load', function () {
            // Si tiene informacion almacenda por defecto esta validado
            // Checkea que se haya realizado el tutorial
            if (!_this.storeData.shipTutorial()) {
                _this.rootPage = TutorialPage;
            }
            if (_this.storeData.getNoticies()) {
                _this.events.publish("push:noticies");
            }
            if (_this.storeData.getUserSession())
                _this.enableLoginMenu(_this.storeData.getUserSession().ConfirmCasteller);
            // Cargar los datos publicos 
            _this.loadPublicacions();
            // Cargar la informacion del usuario al mobil
            if (_this.storeData.getSessionToken()) {
                _this.loadUserInfo();
            }
            else {
                _this.enableAnonimous();
                console.info("No hay toquen");
            }
        });
    };
    /**
     * Carga la informacion del usuario de la session
     */
    AppinyaApp.prototype.loadUserInfo = function () {
        var _this = this;
        this.authenticateService.getInfoUser().subscribe(function (res) {
            _this.storeData.setUserSession(res);
            _this.enableLoginMenu(_this.storeData.getUserSession().ConfirmCasteller);
            // Cargamos castellers si es castelle confirmado
            if (_this.storeData.getUserSession().ConfirmCasteller) {
                _this.loadCastellers();
            }
        }, function (e) {
            /* if (e.status === 401) {
 
                 let alert = this.alertCtrl.create({
                     title: 'Error, No tiene permisos',
                     subTitle: "Renovar Autenticacio",
                     message: "No tiene permisos para acceder al servidor contacte con el administrador",
                     buttons: ['OK']
                 });
                 alert.present();
             }
 
             if (e.status === 500) {
                 let toast = this.toastCtrl.create({
                     message: 'No s\'ha pogut contactar amb el servidor',
                     duration: 3000
                 });
             }
             if (e.status === 502) {
                 let toast = this.toastCtrl.create({
                     message: 'No s\'ha pogut contactar amb el servidor',
                     duration: 3000
                 });
 
             }*/
            console.info(e); //En el caso de no tener acceso al sistema se inhabilita el menu.
            _this.enableAnonimous();
            _this.storeData.clearUser();
            return _this.nav.push(LoginPage);
        });
    };
    /**
     * Cargamos los datos de publicaciones Eventos i Noticias
     */
    AppinyaApp.prototype.loadPublicacions = function () {
        var _this = this;
        var pub = {
            DateEsdeveniments: this.storeData.getDataPubliEsdeveniments(),
            DateNoticies: this.storeData.getDataPubliNoticies(),
            Esdeveniments: null,
            Noticies: null
        };
        this.publicacionsService.getPublicacions(pub).subscribe(function (publi) {
            if (publi.Esdeveniments) {
                _this.storeData.saveEsdeveniments(publi.Esdeveniments, publi.DateEsdeveniments);
            }
            if (publi.Noticies) {
                _this.storeData.saveNoticies(publi.Noticies, publi.DateNoticies);
            }
            Splashscreen.hide();
        }, function (err) {
            _this.toastCtrl.create({
                message: "Error en la actualizacion publica",
                duration: 3000
            });
            Splashscreen.hide();
        });
    };
    AppinyaApp.prototype.loadCastellers = function () {
        var _this = this;
        var message = "Actualitzan els contactes castellers";
        if (!this.storeData.getDataPubliCastellers()) {
            message = 'Es la primera vegada que actualitza contactes, Esperi';
        }
        var loading = this.loadingCtrl.create({
            content: "<div class=\"custom-spinner-container\">\n                    <div class=\"custom-spinner-box\">" + message + "</div>\n                  </div>"
        });
        loading.present();
        this.castellersService.getCasteller(this.storeData.getDataPubliCastellers()).subscribe(function (t) {
            _this.storeData.setCastellers(t.Castellers, t.Date);
            _this.toastCtrl.create({
                message: "Se han cargado correctamente",
                duration: 3000
            });
            loading.dismiss();
        }, function (e) {
            _this.toastCtrl.create({
                message: "Error en la carga",
                duration: 3000
            });
            loading.dismiss();
        });
    };
    AppinyaApp.prototype.enableAnonimous = function () {
        this.menu.enable(false, 'loggedInMenu');
        this.menu.enable(true, 'loggedOutMenu');
    };
    AppinyaApp.prototype.enableLoginMenu = function (isCasteller) {
        isCasteller = isCasteller || false;
        this.loggedInPages.forEach(function (p) {
            if (p.id == 6 || p.id == 7) {
                p.disabled = !isCasteller;
            }
            return p;
        });
        this.menu.enable(true, 'loggedInMenu');
        this.menu.enable(false, 'loggedOutMenu');
    };
    /* disabledPage(page: PageInterface): boolean {
        if (page.id == 6 || page.id == 7) {
            return this.storeData.isCasteller();
        }
        return page.disabled;
    }*/
    AppinyaApp.prototype.platformReady = function () {
        // Call any initial plugins when ready
        this.platform.ready().then(function () {
            console.info("Se ha cargado el dispositivo");
            setTimeout(function () {
                //       Splashscreen.hide();
            }, 2000);
        });
    };
    AppinyaApp.prototype.isActive = function (page) {
        var childNav = this.nav.getActiveChildNav();
        // Tabs are a special case because they have their own navigation
        if (childNav) {
            if (childNav.getSelected() && childNav.getSelected().root === page.tabComponent) {
                return 'primary';
            }
            return;
        }
        if (this.nav.getActive() && this.nav.getActive().component === page.component) {
            return 'primary';
        }
        return;
    };
    return AppinyaApp;
}());
__decorate([
    ViewChild(Nav),
    __metadata("design:type", Nav)
], AppinyaApp.prototype, "nav", void 0);
AppinyaApp = __decorate([
    Component({
        templateUrl: 'app.template.html'
    }),
    __metadata("design:paramtypes", [Events,
        MenuController,
        Platform,
        StoreData,
        AuthenticateService,
        PublicacionsService,
        CastellersService,
        AlertController,
        ToastController,
        LoadingController])
], AppinyaApp);
export { AppinyaApp };
//# sourceMappingURL=app.component.js.map