/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component, ViewChild } from '@angular/core';

import { Events, MenuController, Nav, Platform, AlertController, ToastController, LoadingController } from 'ionic-angular';
import { Splashscreen } from 'ionic-native'; 
 
import { AccountPage } from '../pages/account/account'; 
import { LoginPage } from '../pages/login/login';
import { MapPage } from '../pages/map/map';
import { SignupPage } from '../pages/signup/signup'; 
import { TabsPage } from '../pages/tabs/tabs';
import { TutorialPage } from '../pages/tutorial/tutorial';
import { EsdevenimentListPage } from '../pages/esdeveniment-list/esdeveniment-list';
import { NoticiesListPage } from '../pages/noticies-list/noticies-list';
import { CastellerListPage } from '../pages/castellers-list/castellers-list';
import { SupportPage } from '../pages/support/support';
import { AssistenciaListPage } from '../pages/assistencia-list/assistencia-list'
import { StoreData } from '../providers/storage.data';
import { Publication } from '../entities/entities';
import { PublicacionsService } from "../providers/publicacions.service";
import { AuthenticateService } from "../providers/authenticate.service";
import { CastellersService } from "../providers/castellers.service";
export interface PageInterface {
    id: number;
    title: string;
    component: any;
    icon: string;
    logsOut?: boolean;
    index?: number;
    tabComponent?: any;
    disabled: boolean;
}

@Component({
    templateUrl: 'app.template.html'
})
export class AppinyaApp {
    // the root nav is a child of the root app component
    // @ViewChild(Nav) gets a reference to the app's root nav
    @ViewChild(Nav) nav: Nav;

    appPages: PageInterface[] = [
        { id: 1, title: 'Noticies', component: TabsPage, tabComponent: NoticiesListPage, index: 0, icon: 'paper', disabled: false },
        { id: 2, title: 'Calendari', component: TabsPage, tabComponent: EsdevenimentListPage, index: 1, icon: 'calendar', disabled: false },
        { id: 3, title: 'Map', component: MapPage, icon: 'map', disabled: false },
        { id: 4, title: 'Suport', component: SupportPage, icon: 'flask', disabled: false },

    ];
    loggedInPages: PageInterface[] = [
        { id: 5, title: 'Fitxa Personal', component: AccountPage, icon: 'person', disabled: false },
        { id: 6, title: 'Confirmats', component: AssistenciaListPage, icon: 'thumbs-up', disabled: true },
        { id: 7, title: 'Castellers', component: TabsPage, tabComponent: CastellerListPage, index: 2, icon: 'contacts', disabled: true }
    ];
    loggedOutPages: PageInterface[] = [
        { id: 8, title: 'Accedeix', component: LoginPage, icon: 'log-in', disabled: false },
        { id: 9, title: 'Suport', component: TabsPage, tabComponent: SupportPage, index: 3, icon: 'flask', disabled: false },
        { id: 10, title: 'Registre\'t!', component: SignupPage, icon: 'person-add', disabled: false }
    ];
    rootPage: any;

    constructor(
        public events: Events,
        public menu: MenuController,
        public platform: Platform,
        public storeData: StoreData,
        public authenticateService: AuthenticateService,
        public publicacionsService: PublicacionsService,
        public castellersService: CastellersService,
        public alertCtrl: AlertController,
        public toastCtrl: ToastController,
        public loadingCtrl: LoadingController
    ) {
        console.info("Cosntructor app.component");

        this.platformReady();
        this.rootPage = TabsPage; 
        if (!this.storeData.getSessionToken()) this.enableLoginMenu(true); 


    }
    ngOnInit() {
        console.info("ngOnInit");
        // Load de las variables de la memoria permanente
        this.storeData.loadStore();
        // Activar los eventos de Login y de store
        this.listenEvents();
    }
    logout() {
        this.storeData.logout();
        this.nav.goToRoot(null);
        this.loadPublicacions();
    }
    openPage(page: PageInterface) {

        if (page.index) {
            this.nav.setRoot(page.component, { tabIndex: page.index });
        } else {
            this.nav.setRoot(page.component).catch(() => {
                console.error("Error en la navegacion no tiene un componente asignado en el Nav");
            });
        }

        if (page.logsOut === true) {
            setTimeout(() => {
                this.storeData.logout();
            }, 1000);
        }
    }

    openTutorial() {
        this.nav.setRoot(TutorialPage);
    }
    /**
     * Subscripcion de eventos de la aplicacion todo centralizado en app.components
     */
    listenEvents() {
        // Evento de login
        this.events.subscribe('user:login', () => {
            this.enableLoginMenu(false);
            // Cargar la informacion del usuario al mobil 
            if (this.storeData.getSessionToken()) {
                this.loadUserInfo();
            } else {
                this.enableAnonimous();
                console.info("No hay toquen");
            }
        });

        this.events.subscribe('user:logout', () => {
            this.enableAnonimous();

        });
        // Evento Cuando se carga la base de datos con los datos de trabajo se actualiza la informacion del usuario
        this.events.subscribe('store:load', () => {
            // Si tiene informacion almacenda por defecto esta validado
            // Checkea que se haya realizado el tutorial
            if (!this.storeData.shipTutorial()) {
                this.rootPage = TutorialPage;
            }
            if (this.storeData.getNoticies()) {
                this.events.publish("push:noticies");
            }
            if (this.storeData.getUserSession()) this.enableLoginMenu(this.storeData.getUserSession().ConfirmCasteller);

            // Cargar los datos publicos 
            this.loadPublicacions();

            // Cargar la informacion del usuario al mobil
            if (this.storeData.getSessionToken()) {
                this.loadUserInfo();
            } else {
                this.enableAnonimous();
                console.info("No hay toquen");
            }
            
           
        });

    }
    /**
     * Carga la informacion del usuario de la session
     */
    loadUserInfo(): void {
        this.authenticateService.getInfoUser().subscribe(res => {
            this.storeData.setUserSession(res);
            this.enableLoginMenu(this.storeData.getUserSession().ConfirmCasteller);
            // Cargamos castellers si es castelle confirmado
            if (this.storeData.getUserSession().ConfirmCasteller) {
                this.loadCastellers();
            }
        }, e => {

           /* if (e.status === 401) {

                let alert = this.alertCtrl.create({
                    title: 'Error, No tiene permisos',
                    subTitle: "Renovar Autenticacio",
                    message: "No tiene permisos para acceder al servidor contacte con el administrador",
                    buttons: ['OK']
                });
                alert.present();
            }

            if (e.status === 500) {
                let toast = this.toastCtrl.create({
                    message: 'No s\'ha pogut contactar amb el servidor',
                    duration: 3000
                });
            }
            if (e.status === 502) {
                let toast = this.toastCtrl.create({
                    message: 'No s\'ha pogut contactar amb el servidor',
                    duration: 3000
                });

            }*/
            console.info(e);//En el caso de no tener acceso al sistema se inhabilita el menu.
            this.enableAnonimous(); 
            this.storeData.clearUser();
            return this.nav.push(LoginPage);
        });
    }
    /**
     * Cargamos los datos de publicaciones Eventos i Noticias
     */
    loadPublicacions():void {
        let pub = <Publication>{
            DateEsdeveniments: this.storeData.getDataPubliEsdeveniments(),
            DateNoticies: this.storeData.getDataPubliNoticies(),
            Esdeveniments: null,
            Noticies: null
        };
         this.publicacionsService.getPublicacions(pub).subscribe(
            publi => {
                if (publi.Esdeveniments) {
                    this.storeData.saveEsdeveniments(publi.Esdeveniments, publi.DateEsdeveniments);
                }
                if (publi.Noticies) {
                    this.storeData.saveNoticies(publi.Noticies, publi.DateNoticies);
                }
                Splashscreen.hide();  
            },
            err => {
                this.toastCtrl.create({
                    message: "Error en la actualizacion publica",
                    duration: 3000
                });
                Splashscreen.hide();
            }
        );
    }
    loadCastellers(): void {
        let message: String = "Actualitzan els contactes castellers";
        
        if (!this.storeData.getDataPubliCastellers()) {
            message = 'Es la primera vegada que actualitza contactes, Esperi';
        } 
        let loading = this.loadingCtrl.create({
            content:`<div class="custom-spinner-container">
                    <div class="custom-spinner-box">${message}</div>
                  </div>` 
        });
        loading.present();
        this.castellersService.getCasteller(this.storeData.getDataPubliCastellers()).subscribe(
            t => {
                this.storeData.setCastellers(t.Castellers, t.Date);
                this.toastCtrl.create({
                    message: "Se han cargado correctamente",
                    duration: 3000
                });
                loading.dismiss();
            },
            e => {
                    this.toastCtrl.create({
                    message: "Error en la carga",
                    duration: 3000
                });
                loading.dismiss();
            });
        
    }
    enableAnonimous() {

        this.menu.enable(false, 'loggedInMenu');
        this.menu.enable(true, 'loggedOutMenu');
    }
    enableLoginMenu(isCasteller: Boolean) {
        isCasteller = isCasteller || false;
        this.loggedInPages.forEach(p => {
            if (p.id == 6 || p.id == 7) {
                p.disabled = !isCasteller;
            }
            return p;
        });

        this.menu.enable(true, 'loggedInMenu');
        this.menu.enable(false, 'loggedOutMenu');
    }
    /* disabledPage(page: PageInterface): boolean {
        if (page.id == 6 || page.id == 7) {
            return this.storeData.isCasteller();
        }
        return page.disabled;
    }*/
    platformReady() {
        // Call any initial plugins when ready
        this.platform.ready().then(() => {
            console.info("Se ha cargado el dispositivo");
            setTimeout(() => {
         //       Splashscreen.hide();
            }, 2000);
        });
    }

    isActive(page: PageInterface) {
        let childNav = this.nav.getActiveChildNav();

        // Tabs are a special case because they have their own navigation
        if (childNav) {
            if (childNav.getSelected() && childNav.getSelected().root === page.tabComponent) {
                return 'primary';
            }
            return;
        }

        if (this.nav.getActive() && this.nav.getActive().component === page.component) {
            return 'primary';
        }
        return;
    }
}
