/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component } from '@angular/core';

import { NavParams, ViewController, LoadingController, AlertController, ToastController } from 'ionic-angular';
import { Assistencia, Casteller } from '../../entities/entities';
import { AssistenciaService } from '../../providers/assistencia.service';
import { StoreData } from '../../providers/storage.data';
@Component({
    selector: 'assistencia-edit', 
    templateUrl: 'assistencia-edit.html'
})
export class AssistenciaEditPage  {
    public assistencia: Assistencia;
    public delegats: Array<{ Id: String, Name: String, LastName: String, isChecked: boolean, Casteller: Casteller }> = [];
    public bnew: boolean = false;
    public isenabled: boolean = true;
  constructor( 
    public navParams: NavParams,
    public viewCtrl: ViewController,
    public loadingCtrl: LoadingController,
    public store: StoreData,
    public alertCtrl: AlertController,
    public assistenciaService: AssistenciaService,
    public toastCtrl: ToastController,
  ) { 
      this.assistencia = this.navParams.get("assistencia");  
      this.bnew = (this.navParams.get("type") === "new");
      
      if (this.store.getUserSession().Casteller.AccepInvitations) {
          let loading = this.loadingCtrl.create({
              content: 'Recollint informacio, de la assistencia'
          });
          loading.present();
          this.store.getUserSession().Casteller.AccepInvitations.forEach(
              d => {
                  this.delegats.push({ Id: d.Id, Name: d.Name, LastName: d.LastName, isChecked: false, Casteller: d });
              }
          ); 
          this.assistenciaService.getAssitenciaInvitacions(this.assistencia.Esdeveniment).subscribe(
              t => {
                  loading.dismiss(); 
                  this.isenabled = true;
                  t.forEach(
                      d => {
                          this.delegats.forEach(del => {
                              if (del.Id == d.Casteller.Id) del.isChecked =true;
                          });  
                      }
                  ); 
          },
              e => {
                  this.isenabled= false;
                  loading.dismiss();
          });
          
      }
      
  }
  confirm(): void {
      let loading = this.loadingCtrl.create({
          content: 'Esperi, s\'esta enviant la confirmacio al servidor'
      });
      let lstAssistencia: Assistencia[] = [];
      lstAssistencia.push(this.assistencia);
      this.delegats.forEach(t => {
          if (t.isChecked) lstAssistencia.push(<Assistencia>{ Casteller: t.Casteller, Esdeveniment: this.assistencia.Esdeveniment, NumAcompanyants: 0, Transport: this.assistencia.Transport, Observacions: this.assistencia.Observacions });
      })
      loading.present();
      this.assistenciaService.saveAssistencia(lstAssistencia, loading).subscribe(
          res => {
              this.store.setAssistencia(res); 
              loading.dismiss();
              this.viewCtrl.dismiss(this.assistencia);
              
          },
          err => { 
              loading.dismiss();
              let alert = this.alertCtrl.create({
                  title: 'Error en la confirmacio',
                  subTitle: "No se a podido confirmar (" + err +")"
              });
              alert.present();
          }
      );
  }
  dismiss(data?: any) {
      this.viewCtrl.dismiss(null);
  }
  
}
