/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component, ViewChild } from '@angular/core';

import { AlertController, App, FabContainer, ItemSliding, List, ModalController, NavController, LoadingController, ToastController} from 'ionic-angular';

 
import { AssistenciaService } from '../../providers/assistencia.service';
import { EsdevenimentFilterPage } from './esdeveniment-filter';
import { EsdevenimentViewPage } from '../esdeveniment-det/esdeveniment-view';
import { AssistenciaEditPage } from '../assistencia-det/assistencia-edit';

import { StoreData } from '../../providers/storage.data';
import { Esdeveniment, Assistencia } from '../../entities/entities'; 
@Component({
  selector: 'assistencia-list',
  templateUrl: 'assistencia-list.html'
})
export class AssistenciaListPage {
 
    @ViewChild('assistencialist', { read: List }) assistencialist: List;

  dayIndex = 0;
  queryText = ''; 
  excludeTypes: any [] = [];
  lstAssistencia: Assistencia[]=[]; 
  confDate: string; 
  constructor(
    public alertCtrl: AlertController,
    public app: App,
    public loadingCtrl: LoadingController,
    public modalCtrl: ModalController,
    public navCtrl: NavController,  
    public storeData: StoreData, 
    private assistenciaService: AssistenciaService,
    public toastCtrl: ToastController,
  ) {}

  ionViewDidLoad() {
    this.app.setTitle('Assistencia');
    this.loadAssistencia();
  }
    
       
  loadAssistencia() {
      // Cierra los elementos
      if (this.storeData.getUserSession().Casteller.ConfirmPrecence) {
          this.lstAssistencia = this.storeData.getUserSession().Casteller.ConfirmPrecence; 
      } 
      this.assistencialist && this.assistencialist.closeSlidingItems();  
  }
       
  
  showError(e: String) {
      // create an alert instance
      let alert = this.alertCtrl.create({
          title: 'Error in Esdeveniments ' + e 
      }); 
      alert.present();
  } 
  showDetall(assistencia: Assistencia) {
      let modal = this.modalCtrl.create(AssistenciaEditPage, { assistencia: assistencia, type: "modify" });
      modal.present();

      modal.onWillDismiss((data: any[]) => {
          if (data) {
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat l\'assistencia amb els nous valors',
                  duration: 3000
              });
              toast.present();
          }
      }); 
  }
  deleteConfirm(assistencia: Assistencia) {
      let loading = this.loadingCtrl.create({
          content: 'Esperi, s\'esta enviant la confirmacio al servidor'
      });
      loading.present();
      this.assistenciaService.removeAssistencia([assistencia],loading).subscribe(
          t => {
              this.storeData.setAssistencia(t);
              this.loadAssistencia(); 
              loading.dismiss(); 
              let toast = this.toastCtrl.create({
                  message: 'S\'ha eliminat l\'assistencia amb els nous valors',
                  duration: 3000
              });
              toast.present();
          },
          err => {
              loading.dismiss(); 
              let alert = this.alertCtrl.create({
                  title: 'Error en la anulacio',
                  subTitle: "No se a pogut anular (" + err + ")"
              });
              alert.present();
          }

      );
  }
}
