/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component } from '@angular/core';

import { NavController, NavParams, ModalController, ToastController } from 'ionic-angular';

import { CastellerEditPage } from '../castellers-det/castellers-edit';
import { CastellerSoliPage } from '../castellers-det/castellers-soli';
import { Casteller } from '../../entities/entities';
import { StoreData } from '../../providers/storage.data';
import { CastellersService} from '../../providers/castellers.service';
@Component({
  selector: 'castellers-view',
  templateUrl: 'castellers-view.html'
})
export class CastellerViewPage {
    casteller: Casteller;
    isOwner: boolean = false;
    constructor(
        public navCtrl: NavController,
        public navParams: NavParams,
        public store: StoreData,
        public modalCtrl: ModalController,
        public toastCtrl: ToastController,
        public castellerService: CastellersService
    ) {
        
        this.isOwner = this.navParams.data.Id === this.store.getUserSession().Casteller.Id;
        if (this.isOwner) {
            this.casteller = this.store.getUserSession().Casteller;
        } else {
            this.casteller = this.navParams.data;
        }
  } 
  editCasteller() {
      this.navCtrl.push(CastellerEditPage, this.casteller)
  }
  isJunta(): boolean {
      return this.store.isJunta();
  } 
  addCasteller() {
      this.navCtrl.push(CastellerEditPage)
  }
  solicitudCasteller() { 
      let modal = this.modalCtrl.create(CastellerSoliPage);
      modal.present(); 
      modal.onWillDismiss((data: Casteller) => {
          if (data) {
              this.castellerService.enviaInvitacio(data).subscribe(
                  t => {
                      this.casteller.DelegacioPropia = t;
                      this.store.setDelegacioPropia(t);
                      let toast = this.toastCtrl.create({
                          message: 'S\'ha modificat correctament',
                          duration: 3000
                      });
                  }
                  ,
                  e => {
                      let toast = this.toastCtrl.create({
                          message: ' No se ha podido contactar con el servidor',
                          duration: 3000
                      });
                      toast.present();
                  });
              
          }
      }); 
  }
 
  acceptarInvitacio(casteller: Casteller) {
      this.castellerService.acceptarInvitacio(casteller).subscribe(
          t => {
              this.casteller.Invitations = t || [];
              this.casteller.AccepInvitations.push(casteller);
              this.store.setInvitations(t);
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat correctament',
                  duration: 3000
              });
              toast.present();
          }
          , e => {
              let toast = this.toastCtrl.create({
                  message: ' No se ha podido contactar con el servidor',
                  duration: 3000
              });
              toast.present();
          }
      );
  }
  esborrarInvitacio(casteller: Casteller) {
      this.castellerService.esborrarInvitacio(casteller).subscribe(
          t => {
              this.casteller.Invitations = t || [];
              this.store.setInvitations(this.casteller.Invitations);
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat correctament',
                  duration: 3000
              });
              toast.present();
          }
          , e => {
              let toast = this.toastCtrl.create({
                  message: ' No se ha podido contactar con el servidor',
                  duration: 3000
              });
              toast.present();
          }
      );
  }
  esborrarAcceptacio(casteller: Casteller) {
      this.castellerService.esborrarAcceptacio(casteller).subscribe(
          t => {
              this.casteller.AccepInvitations = t || [];
              this.store.setAcceptacions(this.casteller.AccepInvitations);
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat correctament',
                  duration: 3000
              });
              toast.present();
          }
          , e => {
              let toast = this.toastCtrl.create({
                  message: ' No se ha podido contactar con el servidor',
                  duration: 3000
              });
              toast.present();
          }
      );
  } 
  esborrarDelegacioPropia(casteller: Casteller) {
      this.castellerService.esborrarDelegacioPropia(casteller).subscribe(
          t => {
              this.casteller.DelegacioPropia = t || [];
              this.store.setDelegacioPropia(this.casteller.DelegacioPropia );
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat correctament',
                  duration: 3000
              });
              toast.present();
          }
          , e => {
              let toast = this.toastCtrl.create({
                  message: ' No se ha podido contactar con el servidor',
                  duration: 3000
              });
              toast.present();
          }
      ); 
  }
  esborrarAcceptDelegacioPropia(casteller: Casteller) {
      this.castellerService.esborrarAccepDelegacioPropia(casteller).subscribe(
          t => {
              this.casteller.AccepDelegacioPropia = t || [];
              this.store.setAccepDelegacioPropia(this.casteller.AccepDelegacioPropia);
              let toast = this.toastCtrl.create({
                  message: 'S\'ha modificat correctament',
                  duration: 3000
              });
              toast.present();
          }
          , e => {
              let toast = this.toastCtrl.create({
                  message: ' No se ha podido contactar con el servidor',
                  duration: 3000
              });
              toast.present();
          }
      );
  }
}

