/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component } from '@angular/core';

import { NavParams } from 'ionic-angular';
import { AlertController, NavController, ModalController, ToastController, LoadingController } from 'ionic-angular';
import { EsdevenimentEditPage } from './esdeveniment-edit';
import { AssistenciaEditPage } from '../assistencia-det/assistencia-edit';
 
import { Assistencia, Esdeveniment } from '../../entities/entities';
import { StoreData } from '../../providers/storage.data';
import { AssistenciaService } from '../../providers/assistencia.service'

@Component({
  selector: 'esdeveniment-detail',
  templateUrl: 'esdeveniment-view.html'
})
export class EsdevenimentViewPage {
    esdeveniment: Esdeveniment;
    puedeConfirmar: boolean;
    puedeDesconfirmar: boolean;
    constructor(
        public navCtrl: NavController,
        public navParams: NavParams,
        public alertCtrl: AlertController,
        public store: StoreData,
        public modalCtrl: ModalController,
        public loadingCtrl: LoadingController,
        public toastCtrl: ToastController,
        public assistenciaService: AssistenciaService) {

        this.esdeveniment = navParams.data;

        if (this.store.isCasteller()) {
            let assistencia: Assistencia[] = this.store.getUserSession().Casteller.ConfirmPrecence;
            if (!assistencia) {
                this.puedeConfirmar = true;
                this.puedeDesconfirmar = false;
            }else {
               
                this.puedeDesconfirmar = false;
                assistencia.forEach(it => { if (it.Esdeveniment.Id === this.esdeveniment.Id) this.puedeDesconfirmar = true; })
                this.puedeConfirmar = !this.puedeDesconfirmar;
            }
        } else {
            this.puedeConfirmar = false;
            this.puedeDesconfirmar = false;
        } 
    }
    isJunta(): boolean {
        return this.store.isJunta();
    }  
  
  editEsdeveniment() {
      this.navCtrl.push(EsdevenimentEditPage, this.esdeveniment)
  }
  addEsdeveniment() {
      this.navCtrl.push(EsdevenimentEditPage)
  }
  showConfirm() {
      let assistencia = <Assistencia>{
          Casteller: this.store.getUserSession().Casteller,
          Esdeveniment: this.esdeveniment,
          Transport: null
      };
      if (this.esdeveniment.OfereixTransport || this.store.getUserSession().Casteller.AccepInvitations) {
          let modal = this.modalCtrl.create(AssistenciaEditPage, { assistencia: assistencia, type: "new" });
          modal.present();

          modal.onWillDismiss((data: any[]) => {
              if (data) {
                  this.puedeConfirmar = false;
                  this.puedeDesconfirmar = true;
                  let toast = this.toastCtrl.create({
                      message: 'S\'ha confirmat l\'assistencia correctament',
                      duration: 3000
                  });
                  toast.present();
              }
          });
      } else {
          let loading = this.loadingCtrl.create({
              content: 'Esperi, s\'esta enviant la confirmacio al servidor'
          });
          loading.present();
          this.assistenciaService.saveAssistencia([assistencia], loading).subscribe(
              res => {
                  this.puedeConfirmar = false;
                  this.puedeDesconfirmar = true;
                  this.store.setAssistencia(res);
                  loading.dismiss();
                  let toast = this.toastCtrl.create({
                      message: 'S\'ha confirmat l\'assistencia correctament',
                      duration: 3000
                  });
                  toast.present();
              },
              err => {
                  loading.dismiss();
                  let alert = this.alertCtrl.create({
                      title: 'Error en la confirmacio',
                      subTitle: "No se a podido confirmar (" + err + ")"
                  });
                  alert.present();
              }
          );
      }
  }
  desconfirmEsdeveniment() {

      let loading = this.loadingCtrl.create({
          content: 'Esperi, s\'esta enviant la confirmacio al servidor'
      });
      loading.present();
      this.assistenciaService.removeAssistencia([<Assistencia>{
          Casteller: this.store.getUserSession().Casteller, Esdeveniment: this.esdeveniment, NumAcompanyants: 0, Transport: false
      }], loading).subscribe(
          t => { 
              this.puedeConfirmar = true;
              this.puedeDesconfirmar = false;
              this.store.setAssistencia(t);
              loading.dismiss(); 
              let toast = this.toastCtrl.create({
                  message: 'S\'ha eliminat l\'assistencia amb els nous valors',
                  duration: 3000
              });
              toast.present();
          },
          err => {
              loading.dismiss();
              let alert = this.alertCtrl.create({
                  title: 'Error en la anulacio',
                  subTitle: "No se a pogut anular (" + err + ")"
              });
              alert.present();
          }

      );
  }
    /*
    deleteConfirm(assistencia: Assistencia) {
      let loading = this.loadingCtrl.create({
          content: 'Esperi, s\'esta enviant la confirmacio al servidor'
      });
      loading.present();
      this.esdevenimentService.eliminarAssistencia([assistencia]).subscribe(
          t => {
              this.storeData.setAssistencia(t);
              this.loadEsdeveniments();
              loading.dismiss();
              let toast = this.toastCtrl.create({
                  message: 'S\'ha eliminat l\'assistencia amb els nous valors',
                  duration: 3000
              });
              toast.present();
          },
          err => {
              loading.dismiss();
              let alert = this.alertCtrl.create({
                  title: 'Error en la anulacio',
                  subTitle: "No se a pogut anular (" + err + ")"
              });
              alert.present();
          }

      );
  }
    */
}
