/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import {  Component } from '@angular/core';
import { NgForm } from '@angular/forms';

import { Events, AlertController, NavController, LoadingController } from 'ionic-angular';

import { SignupPage } from '../signup/signup';
import { TabsPage } from '../tabs/tabs';
import { StoreData } from '../../providers/storage.data'; 
 
import { AuthenticateService } from "../../providers/authenticate.service";
@Component({
  selector: 'page-user',
  templateUrl: 'login.html'
})
export class LoginPage { 
  login: {username?: string, password?: string} = {};
  submitted = false;

  constructor(
      public navCtrl: NavController,
      public storeData: StoreData,
      public authenticateService: AuthenticateService,
      public events: Events,
      public alertCtrl: AlertController,
      public loadingCtrl: LoadingController
        ) { }

  onLogin(form: NgForm) {
    this.submitted = true;

    if (form.valid) {
        let loading = this.loadingCtrl.create({
            content: 'Esperi, s\'esta enviant la confirmacio al servidor'
        });
        loading.present();
        this.authenticateService.login(this.login.username, this.login.password).subscribe(
            tk => {
                this.onLoginResult(tk);
                loading.dismiss();
            }, err => {
                console.info(err);
                loading.dismiss();
            let alert = this.alertCtrl.create({
                title: 'Error en usuari o Password',
                subTitle: "Validi que l\'usuari i el password siguin correctes.",
                buttons: ['OK']
            });
            alert.present();
        }); 
    }
  }
  onLoginResult(tk: any) {
      if (tk != null && tk !="") {  
          this.storeData.login(this.login.username, tk);
          this.navCtrl.push(TabsPage);
          this.navCtrl.resize();
           
      }
  }  
  onSignup() {
    this.navCtrl.push(SignupPage);
  }
}
