/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Component } from '@angular/core';
import { ActionSheet, ActionSheetController, Config, NavController, Events } from 'ionic-angular';
import { InAppBrowser } from 'ionic-native'; 
import { StoreData } from '../../providers/storage.data'; 

import { Noticies } from '../../entities/entities' 
 
import { NoticiesService} from '../../providers/noticies.service';

@Component({
    selector: 'noticies-list',
    templateUrl: 'noticies-list.html'
})
export class NoticiesListPage { 
    actionSheet: ActionSheet;
    noticies: Noticies[] = [];

    constructor(
        public actionSheetCtrl: ActionSheetController,
        public navCtrl: NavController,
        public config: Config,
        public noticiesService: NoticiesService, 
        public store: StoreData,
        public events: Events
    ) { 
        this.events.subscribe('push:noticies', () => {
            console.log("Notificacion de noticias NoticiesList catched");
            this.noticies = this.store.getNoticies();
        });
    }

    ionViewDidEnter() { 
        if (this.noticies.length == 0 ) {
            if (this.store.getNoticies())
                this.noticies = this.store.getNoticies();
            else {
                this.noticies = [];
            }
        }
        this.store.clearNotification(); 
    }
     

    goToUrl(not: Noticies) {
        new InAppBrowser(not.Url, '_blank');
    }

    openShare(not: Noticies) {
        let mode = this.config.get('mode'); 
        let actionSheet = this.actionSheetCtrl.create({
            title: 'Correu electronic de  ' + not.UserInfo.Name + " " + not.UserInfo.LastName,
            buttons: [
                {
                    text: 'Copiar Correu',
                    icon: 'share',
                    handler: ($event: Event) => { 
                        if ((window as any)['cordova'] && (window as any)['cordova'].plugins.clipboard) {
                            (window as any)['cordova'].plugins.clipboard.copy(not.UserInfo.Email);
                        }
                    }
                },
                {
                    text: `Email ( ${not.UserInfo.Email} )`,
                    icon: mode !== 'ios' ? 'mail' : null,
                    handler: () => {
                        window.open('mailto:' + not.UserInfo.Email);
                    }
                },
                {
                    text: 'Cancel',
                    role: 'cancel'
                }
            ]
        }); 
        actionSheet.present();
    }
     
}
