var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Headers, RequestOptions } from '@angular/http';
import { Observable } from 'rxjs/Rx';
import { StoreData } from './storage.data';
import { AlertController, ToastController } from 'ionic-angular';
/**
 * Abstraccion del servicio para gestionar metodo comunmente llamados
 */
var RestService = (function () {
    function RestService(store, alertCtrl, toastCtrl) {
        this.store = store;
        this.alertCtrl = alertCtrl;
        this.toastCtrl = toastCtrl;
        this.rootPath = 'http://82.223.24.241'; // 'http://localhost/AppinyaServer';//
        this.mockEnabled = false;
        if (this.mockEnabled)
            console.log("RestService - Modo Mock Activado");
    }
    /**
     * Cabecera Standart de la peticion HTTP
     */
    RestService.prototype.getHeaders = function () {
        var headers = new Headers({ 'Content-Type': 'application/json' });
        headers.append('Authorization', 'Bearer ' + this.store.getSessionToken());
        headers.append("Access-Control-Allow-Headers", 'Origin, X-Requested-With, Content-Type, Accept, Authorization');
        headers.append("Access-Control-Allow-Methods", "GET, POST, PUT, DELETE");
        headers.append("Access-Control-Allow-Origin", "*");
        headers.append("Access-Control-Allow-Credentials", "true");
        var options = new RequestOptions({ headers: headers });
        return options;
    };
    /**
     * Carga las cabeceras sin la variable Authenication
     */
    RestService.prototype.getHeadersWithOutToken = function () {
        var headers = new Headers();
        headers.append("Content-Type", 'application/json');
        headers.append("Access-Control-Allow-Headers", 'Content-Type');
        headers.append("Access-Control-Allow-Methods", "GET, POST, PUT, DELETE");
        headers.append("Access-Control-Allow-Origin", "*");
        headers.append("Access-Control-Allow-Credentials", "true");
        return headers;
    };
    /**
     * Carga las cabeceras que necesita la creacion del Token
     */
    RestService.prototype.getHeadersForToken = function () {
        var headers = new Headers();
        headers.append('content-type', 'application/x-www-form-urlencoded');
        headers.append('accept', 'application/x-www-form-urlencoded');
        headers.append("Access-Control-Allow-Origin", "*");
        return headers;
    };
    RestService.prototype.handlerErrorForForms = function (errorResponse, loading) {
        if (errorResponse.status == 400) {
            var log = "";
            errorResponse.json().ModelState.errors.forEach(function (errorLine) {
                log += errorLine;
            });
            var alert_1 = this.alertCtrl.create({
                title: 'Error en el formulari ',
                subTitle: log,
                buttons: ['OK']
            });
            alert_1.present();
        }
        var errorMsg = errorResponse.message || "Error en la conexi\u00F3n del servicio";
        if (errorResponse.status === 500) {
            var alert_2 = this.alertCtrl.create({
                title: 'Error, En el servidor ',
                subTitle: "Error status " + errorResponse.status,
                message: "Error en el servidor " + errorMsg,
                buttons: ['OK']
            });
            alert_2.present();
            if (loading)
                loading.dismissAll();
            return Observable.empty();
        }
        if (errorResponse.message === 502) {
            var toast = this.toastCtrl.create({
                message: 'No s\'ha pogut contactar amb el servidor',
                duration: 3000
            });
            toast.present();
            if (loading)
                loading.dismissAll();
            return Observable.empty();
        }
        console.error(errorMsg);
    };
    /**
     * Recoge los errors de comunicacion HTTP
     * @param error
     */
    RestService.prototype.handleError = function (errorResponse, loading) {
        // Permisos en la peticion
        if (errorResponse.status === 401) {
            var alert_3 = this.alertCtrl.create({
                title: 'Error, No tiene permisos',
                subTitle: "Renovar Autenticacio",
                message: "No tiene permisos para acceder al servidor contacte con el administrador",
                buttons: ['OK']
            });
            alert_3.present();
            return Observable.throw('Usuario no autorizado');
        }
        var errorMsg = errorResponse.message || "Error en la conexi\u00F3n del servicio";
        if (errorResponse.status === 500) {
            var alert_4 = this.alertCtrl.create({
                title: 'Error, En el servidor ',
                subTitle: "Error status " + errorResponse.status,
                message: "Error en el servidor " + errorMsg,
                buttons: ['OK']
            });
            alert_4.present();
            if (loading)
                loading.dismissAll();
            return Observable.empty();
        }
        if (errorResponse.status === 502) {
            var toast = this.toastCtrl.create({
                message: 'No s\'ha pogut contactar amb el servidor',
                duration: 3000
            });
            toast.present();
            if (loading)
                loading.dismissAll();
            return Observable.empty();
        }
        console.error(errorResponse.status + " " + errorMsg);
        // Error del resto un Error
        return Observable.throw(errorMsg);
    };
    return RestService;
}());
RestService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [StoreData, AlertController, ToastController])
], RestService);
export { RestService };
//# sourceMappingURL=RestBase.service.js.map