﻿/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Headers, RequestOptions } from '@angular/http';
import { Observable } from 'rxjs/Rx';

import { StoreData } from './storage.data';
import { AlertController, ToastController, Loading } from 'ionic-angular';

/**
 * Abstraccion del servicio para gestionar metodo comunmente llamados
 */
@Injectable()
export class RestService {
    rootPath: string = 'http://82.223.24.241'; // 'http://localhost/AppinyaServer';//
    mockEnabled: Boolean = false;
    constructor(public store: StoreData, public alertCtrl: AlertController, public toastCtrl: ToastController) {
        if (this.mockEnabled) console.log("RestService - Modo Mock Activado");
    }

    /**
     * Cabecera Standart de la peticion HTTP
     */
    public getHeaders() {   
        let headers = new Headers({ 'Content-Type': 'application/json' });
        headers.append('Authorization', 'Bearer ' + this.store.getSessionToken());
        headers.append("Access-Control-Allow-Headers", 'Origin, X-Requested-With, Content-Type, Accept, Authorization');
        headers.append("Access-Control-Allow-Methods", "GET, POST, PUT, DELETE");
        headers.append("Access-Control-Allow-Origin", "*");
        headers.append("Access-Control-Allow-Credentials", "true");
        let options = new RequestOptions({ headers: headers });
        return options; 
       
    } 
    /**
     * Carga las cabeceras sin la variable Authenication
     */
    public getHeadersWithOutToken() {
       
        let headers = new Headers(); 
        headers.append("Content-Type", 'application/json');
        headers.append("Access-Control-Allow-Headers", 'Content-Type');
        headers.append("Access-Control-Allow-Methods", "GET, POST, PUT, DELETE");
        headers.append("Access-Control-Allow-Origin", "*");
        headers.append("Access-Control-Allow-Credentials", "true");
         
        return headers;
    }
    /**
     * Carga las cabeceras que necesita la creacion del Token
     */
    public getHeadersForToken() {
        let headers = new Headers();
        headers.append('content-type', 'application/x-www-form-urlencoded');
        headers.append('accept', 'application/x-www-form-urlencoded');
        headers.append("Access-Control-Allow-Origin", "*");
        return headers;
    }


    public handlerErrorForForms(errorResponse: any, loading?: Loading) {

        if (errorResponse.status == 400) {
            var log:string= "";
            errorResponse.json().ModelState.errors.forEach(function (errorLine:any) {
                log += errorLine;
            })
            let alert = this.alertCtrl.create({
                title: 'Error en el formulari ',
                subTitle: log,
                buttons: ['OK']
            });
            alert.present();
        } 

        let errorMsg = errorResponse.message || `Error en la conexión del servicio`
        if (errorResponse.status === 500) {
            let alert = this.alertCtrl.create({
                title: 'Error, En el servidor ',
                subTitle: "Error status " + errorResponse.status,
                message: "Error en el servidor " + errorMsg,
                buttons: ['OK']
            });
            alert.present();
            if (loading) loading.dismissAll();
            return Observable.empty();
        }
        if (errorResponse.message === 502) {
            let toast = this.toastCtrl.create({
                message: 'No s\'ha pogut contactar amb el servidor',
                duration: 3000
            });
            toast.present();
            if (loading) loading.dismissAll();
            return Observable.empty();
        }
        console.error(errorMsg); 
    }
    /**
     * Recoge los errors de comunicacion HTTP
     * @param error
     */
    public handleError(errorResponse: any, loading?: Loading) {
        // Permisos en la peticion
        if (errorResponse.status === 401) {
             
            let alert = this.alertCtrl.create({
                title: 'Error, No tiene permisos',
                subTitle: "Renovar Autenticacio",
                message:"No tiene permisos para acceder al servidor contacte con el administrador",
                buttons: ['OK']
            });
            alert.present();
            return Observable.throw('Usuario no autorizado');
        }

        let errorMsg = errorResponse.message || `Error en la conexión del servicio`
        if (errorResponse.status === 500) {
            let alert = this.alertCtrl.create({
                title: 'Error, En el servidor ',
                subTitle: "Error status " + errorResponse.status,
                message: "Error en el servidor " + errorMsg,
                buttons: ['OK']
            });
            alert.present();
            if (loading) loading.dismissAll();
            return Observable.empty();
        }
        if (errorResponse.status === 502) {
            let toast = this.toastCtrl.create({
                message: 'No s\'ha pogut contactar amb el servidor',
                duration: 3000
            });
            toast.present();
            if (loading) loading.dismissAll();
            return Observable.empty();
        }
        console.error(errorResponse.status  + " " + errorMsg); 
        // Error del resto un Error
        return Observable.throw(errorMsg);
 
    }

    
   
}
