/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Rx'; 
import { RestService } from './RestBase.service'; 
import {  Http } from '@angular/http'; 
import { StoreData } from './storage.data';
import { AlertController, ToastController, Loading } from 'ionic-angular';
import { MappingLocal } from './mapping.local';
import { Assistencia, Esdeveniment } from '../entities/entities';

@Injectable()
export class AssistenciaService extends RestService{ 
    
    constructor(private http: Http, public store: StoreData, public alertCtrl: AlertController, public mapping: MappingLocal, public toastCtrl: ToastController) {
        super(store, alertCtrl, toastCtrl);
    }
    saveAssistencia(assis: Assistencia[], loading: Loading): Observable<Assistencia[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/assistencies.json`, this.getHeaders()).map(this.mapping.mapAssistenciaResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.put(`${this.rootPath}/api/Assistencia/confirm`, JSON.stringify(assis), this.getHeaders())
                .map(this.mapping.mapAssistenciaResponse).catch(e => this.handleError(e, loading));
            return assistencia$;
        }
    }

    removeAssistencia(assis: Assistencia[], loading: Loading): Observable<Assistencia[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/assistencies.json`, this.getHeaders()).map(this.mapping.mapAssistenciaResponse).catch(e => this.handleError(e, loading));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Assistencia/remove`, JSON.stringify(assis), this.getHeaders())
                .map(this.mapping.mapAssistenciaResponse).catch(e => this.handleError(e));
            return assistencia$;
        }
    }

    getAssitenciaInvitacions(esdeveniment: Esdeveniment): Observable<Assistencia[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/assistencies.json`,   this.getHeaders()).map(this.mapping.mapAssistenciaResponse);
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Assistencia/assitenciaInvitacions`, JSON.stringify(esdeveniment), this.getHeaders())
                .map(this.mapping.mapAssistenciaResponse);
            return assistencia$;
        }
    }

   
  }
  
 