/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { RequestOptions, Http, Response, Headers } from '@angular/http';
import { Observable } from 'rxjs/Rx';
import { StoreData } from './storage.data';
import { AlertController, ToastController } from 'ionic-angular';
import { RestService } from './RestBase.service';
import { UserInfo } from '../entities/UserInfo'
import { Signup } from '../entities/Signup'
import { MappingLocal } from './mapping.local';
/**
 * Clase responsable de las acciones del usuario sobre su cuenta
 */
@Injectable()
export class AuthenticateService extends RestService{

   
    constructor(private http: Http, public store: StoreData, public alertCtrl: AlertController, public mapping: MappingLocal, public toastCtrl: ToastController) {
        super(store, alertCtrl, toastCtrl);
    }
    /**
     * Metodo para enviar el correo de confirmacion para saber si el usuario tiene el correo indicado
     * @param oldpass
     * @param newpass
     * @param confirmpass
     */
    sendMailConfirmation(): Observable<Response> {
        let sendConfirm$ = this.http.get(`${this.rootPath}/api/User/sendMailConfirmation`,this.getHeaders());
        return sendConfirm$;
    }
    /**
     *  * Metodo para enviar el correo de confirmacion para saber si el usuario tiene el correo indicado
     * @param name
     * @param lastName
     * @param email
     * @param password
     * @param repassword
     */
    signUp(signup: Signup): Observable<Response> {
        let signUp1$ = this.http.post(`${this.rootPath}/api/User/registerUser`, JSON.stringify(signup), this.getHeaders()).catch(e => this.handlerErrorForForms(e));
        return signUp1$;
    }
    /**
     * Metodo para cambiar el password
     * @param oldpass
     * @param newpass
     * @param confirmpass
     */
    changePassword(oldpass: String, newpass: String, confirmpass: String): Observable<Response>{
        let changePass$ = this.http.post(`${this.rootPath}/api/User/changePassword`, JSON.stringify({ OldPassword: oldpass, NewPassword: newpass, ConfirmPassword: confirmpass }), this.getHeaders()).catch(e => this.handlerErrorForForms(e));
        return changePass$;
    }
    /**
     * Metodo Login
     * @param user
     * @param pass
     */
    login(user: String, pass: String): Observable<String> { 
        let token$ = this.http.post(`${this.rootPath}/Token`, "UserName=" + user + "&Password=" + pass + "&grant_type=password", this.getHeadersForToken())
            .map(this.mapToken)
            .catch(e => this.handleError(e));
        return token$;
    }
    /**
     * Mapea la entidad
     * @param response
     */
    private mapToken(response: Response): String {
        return response.json().access_token;
    }
    /**
     * Recoger la informacion del Usuario actualizada
     * @param tk
     */ 
    getInfoUser(): Observable<UserInfo> { 
        if (this.mockEnabled) {
            console.warn("Mock Enabled getInfoUser");
            let token$ = this.http.get(`assets/data/InfoGetUser.json`, this.getHeaders()).map(this.mapping.mapUserInfoResponse);
            return token$;
        } else {
            console.debug("Acceso a Refresh " + this.store.getSessionToken);
            let token$ = this.http.get(`${this.rootPath}/api/User/getUserInfo`, this.getHeaders()).map(this.mapping.mapUserInfoResponse).catch(e => this.handleError(e));
            return token$;
        }
    } 

    oblidarConstrasenya(user:String): Observable<Boolean> {
        if (this.mockEnabled) {
            console.warn("Mock Enabled changePassword");
            let token$ = this.http.get(`assets/data/InfoGetUser.json`, this.getHeaders()).map(t => { return true; });
            return token$;
        } else {
            console.debug("Acceso a Refresh " + this.store.getSessionToken);
            let token$ = this.http.get(`${this.rootPath}/api/User/oblidarConstrasenya?user=` + user, this.getHeaders()).map(t => { return true; }).catch(e => this.handleError(e));
            return token$;
        }
    } 
    
 
}
  