/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Rx';
import { PublicationCasteller, Casteller } from '../entities/entities';
import { RestService } from './RestBase.service'; 
import { Http, Response } from '@angular/http'; 
import { StoreData } from './storage.data';
import { AlertController, ToastController } from 'ionic-angular';
import { MappingLocal } from './mapping.local';

@Injectable()
export class CastellersService extends RestService{
    
    constructor(private http: Http, public store: StoreData, public alertCtrl: AlertController, public mapping: MappingLocal, public toastCtrl: ToastController) {
        super(store, alertCtrl, toastCtrl);
    }
   /**
    * Metodo de REST para obtener el listado de Castellers
    */
    getCasteller(data:String): Observable<PublicationCasteller>{
        if (this.mockEnabled) {
            console.warn("Mock Enabled getCasteller");
            let castellers$ = this.http.get(`assets/data/publicacionsCastellers.json`, this.getHeaders()).map(this.mapping.mapPublicationCastellerResponse).catch(e => this.handleError(e));
            return castellers$;
        } else {
            data = data || "";
            let castellers$ = this.http.get(`${this.rootPath}/api/Casteller/getAll?date=${data}`, this.getHeaders())
                .map(this.mapping.mapPublicationCastellerResponse);
            return castellers$;
        }
      
    }
    enviaInvitacio(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/enviaInvitacio`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        } 
    } 
    esborrarInvitacio(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/esborrarInvitacio`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        }
    }
    esborrarAcceptacio(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/esborrarAcceptacio`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        } 
    }
    acceptarInvitacio(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.get(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/acceptarInvitacio`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        }

    } 
    esborrarAccepDelegacioPropia(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.post(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/esborrarAccepDelegacioPropia`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        } 
    }
    esborrarDelegacioPropia(cas: Casteller): Observable<Casteller[]> {
        if (this.mockEnabled) {
            let assistencia$ = this.http.post(`assets/data/delega.json`, this.getHeaders()).map(this.mapping.mapCastellerResponse).catch(e => this.handleError(e));
            return assistencia$;
        } else {
            let assistencia$ = this.http.post(`${this.rootPath}/api/Casteller/esborrarDelegacioPropia`, JSON.stringify(cas), this.getHeaders())
                .map(this.mapping.mapCastellerResponse);
            return assistencia$;
        }

    }
    
 
 
 
}


 
