/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Rx';
import { Esdeveniment } from '../entities/entities';
import { RestService } from './RestBase.service'; 
import {  Http, Response } from '@angular/http'; 
import { StoreData } from './storage.data';
import { AlertController, ToastController } from 'ionic-angular';
import { MappingLocal } from './mapping.local';  
@Injectable()
export class EsdevenimentService extends RestService{
    
    constructor(private http: Http, public store: StoreData, public alertCtrl: AlertController, public mapping: MappingLocal, public toastCtrl: ToastController ) {
        super(store, alertCtrl, toastCtrl);
    }
   /**
    * Metodo de REST para obtener el listado de eventos
    */
    getEsdeveniments(filter: number): Observable<Esdeveniment[]>{
        if (this.mockEnabled) {
            let esdeveniments$ = this.http.get(`assets/data/esdeveniments.json`, this.getHeaders()).map(this.mapping.mapEsdevenimentResponse).catch(e => this.handleError(e));
            return esdeveniments$;
        } else {
            let esdeveniments$ = this.http.post(`${this.rootPath}/api/Esdeveniment/getAll`, JSON.stringify({ DataPublicacio: null, TipusEsdeveniments: filter }), this.getHeaders())
                .map(this.mapping.mapEsdevenimentResponse);
            return esdeveniments$;
        }
      
    }

    getEsdevenimentsForUser(): Observable<Esdeveniment[]> {
        if (this.mockEnabled) {
            let esdeveniments$ = this.http.get(`assets/data/esdeveniments.json`, this.getHeaders()).map(this.mapping.mapEsdevenimentResponse).catch(e => this.handleError(e));
            return esdeveniments$;
        } else {
            let esdeveniments$ = this.http.get(`${this.rootPath}/api/Esdeveniment/GetForUser`, this.getHeaders())
                .map(this.mapping.mapEsdevenimentResponse);
            return esdeveniments$;
        }    
    }
    
    /**
        * Metodo Rest Get Id 
        * @param id
        */
        get(id: string): Observable<Esdeveniment> {
            let esdeveniments$ = this.http
            .get(`${this.rootPath}/Esdeveniment/${id}`, this.getHeaders())
                .map(this.mapping.mapEsdevenimentResponse).catch(e => this.handleError(e)); 
            return esdeveniments$; 
        }

/**
 * Salvar cambios d'evento
 * @param esdeveniment
 */
  save(esdeveniment: Esdeveniment) : Observable<Response>{ 
      return this.http
          .put(`${this.rootPath}/Esdeveniment/${esdeveniment.Id}`, JSON.stringify(esdeveniment), this.getHeaders());
  }
 
 
}


 
