﻿/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Response } from '@angular/http';
import { Assistencia, Casteller, Noticies, Esdeveniment, Publication, PublicationCasteller} from '../entities/entities'; 
import { UserInfo } from '../entities/UserInfo'; 
@Injectable()
export class MappingLocal  {

    constructor() {
      
    } 
    public mapAssistenciaResponse(response: Response): Assistencia[] {
        return response.json().map(toAssistencia);
    }
    public mapCastellerResponse(response: Response) {
        return response.json().map(toCasteller);
    }
    public mapPublicationCastellerResponse(response: Response): PublicationCasteller {
        return toPublicationCasteller(response.json());
    }
    public mapCasteller(r: any): Casteller {
        return toCasteller(r);
    }
    public mapUserInfoResponse(response: Response): UserInfo {
        return toUserInfo(response.json());
    }
    public mapUserInfo(r: any): UserInfo {
        return toUserInfo(r);
    }
    public mapNoticiesPublicacions(response: Response): Publication {
        return toPublicacions(response.json());
    }
    public mapNoticiesResponse(response: Response): Noticies[] {
        return response.json().map(toNoticia);
    }
    public mapNoticies(r: any): Noticies {
        return toNoticia(r);
    }
    public mapEsdevenimentResponse(response: Response): Esdeveniment[] { 
        return response.json().map(toEsdeveniment);
    }
    public mapEsdeveniment(r: any): Esdeveniment {
        return toEsdeveniment(r);
    }

}

 
 /**
 * Mapeador del Esdeveniment
 * @param r Entidad JSON
 */
function toEsdeveniment(r: any): Esdeveniment {
    if (!r) return null; 
    let esdeveniment = <Esdeveniment>({
        Id: r.Id,
        Tittle: r.Tittle,
        Description: r.Description,
        DateIni: r.DateIniStr,
        DateFin: r.DateFinStr,
        HourIni: r.HourIniStr,
        HourFin: r.HourFinStr,
        EventTypeId: r.EventTypeId,
        EventType: r.EventType,
        OfereixTransport: r.OfereixTransport

    });
    console.log('Parsed Esdeveniment:', esdeveniment);
    return esdeveniment;
}
/**
 * Funcio de mapaix de l'informacio del usuari
 * @param response
 */
function toUserInfo(r: any): UserInfo { 
    if (!r) return null; 
    let userInfo = <UserInfo>({
        Id: r.Id,
        Name: r.Name,
        LastName: r.LastName,
        Email: r.Email,
        ConfirmEmail: r.ConfirmEmail,
        ConfirmCasteller: r.ConfirmCasteller,
        PhoneNumber: r.PhoneNumber,
        Privilege: r.Privilege,
        Casteller: toCasteller(r.Casteller)
    });


    return userInfo;
}
function toPublicationCasteller(r: any): PublicationCasteller {
    if (!r) return null;
    let pubcas = <PublicationCasteller>({
        Castellers : (r.Castellers) ? r.Castellers.map(toCasteller) : null,
        Date : r.Date
    });
    console.log('Parsed Noticia:', pubcas);
    return pubcas;

}
function toPublicacions(r: any): Publication{
    if (!r) return null;
    let pub = <Publication>({
        DateEsdeveniments: r.DateEsdeveniments,
        DateNoticies: r.DateNoticies,
        Esdeveniments: (r.Esdeveniments) ? r.Esdeveniments.map(toEsdeveniment) : null,
        Noticies: (r.Noticies) ? r.Noticies.map(toNoticia) : null
    });
    console.log('Parsed Publication:', pub);
    return pub;

}
function toNoticia(r: any): Noticies {
    if (!r) return null;
    let noticia = <Noticies>({
        Id: r.Id,
        Tittle: r.Tittle,
        Description: r.Description,
        Date: r.DateStr,
        Url: r.Url,
        UserInfo: toUserInfo(r.UserRef)
    });
    console.log('Parsed Noticia:', noticia);
    return noticia;

}
function toAssistencia(r: any): Assistencia {
    if (!r) return null;
    let assistencia = <Assistencia>(
        {
            Casteller: toCasteller(r.Casteller),
            Esdeveniment: toEsdeveniment(r.Esdeveniment),
            Transport: r.Transport,
            NumAcompanyants: r.NumAcompanyants,
            Observacions: r.Observacions
        });
    return assistencia;
}
function toCasteller(r: any): Casteller {
    if (!r) return null;
    let casteller = <Casteller>(
        {
            Id: r.Id,
            Alias:r.Alias,
            Name:r.Name,
            LastName:r.LastName,
            BirthDay: r.BirdhDay,
            Cancelation: r.Cancelation,
            CancelationDate: r.CancelationDate,
            ConfirmPrecence: (r.ConfirmPrecence) ? r.ConfirmPrecence.map(toAssistencia) : null,
            DateSignUp: r.DateSignUp, 
            Depts: r.Depts,
            Email: r.Email,
            HasShirt: r.HasShirt,
            IdUser: r.IdUser,
            Invitations: (r.Invitations) ? r.Invitations.map(toCasteller) : [],
            DelegacioPropia: (r.DelegacioPropia) ? r.DelegacioPropia.map(toCasteller) : [],
            AccepDelegacioPropia: (r.AccepDelegacioPropia) ? r.AccepDelegacioPropia.map(toCasteller) : [],
            AccepInvitations: (r.AccepInvitations) ? r.AccepInvitations.map(toCasteller) : [],
            Phone1: r.Phone1,
            Phone2: r.Phone2,
            
            
        }
    );
    return casteller;

}