/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 Espaa (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Rx';
import { Noticies } from '../entities/entities';
import { RestService } from './RestBase.service'; 
import {  Http, Response, Headers } from '@angular/http'; 
import { StoreData } from './storage.data';
import { AlertController, ToastController } from 'ionic-angular';
import { MappingLocal } from './mapping.local';
@Injectable()
export class NoticiesService extends RestService{
    
    constructor(private http: Http, public store: StoreData, public alertCtrl: AlertController, public mapping: MappingLocal, public toastCtrl: ToastController) {
        super(store, alertCtrl, toastCtrl);
    }
   /**
    * Metodo de REST para obtener el listado de Noticias
    */
    getNoticies(): Observable<Noticies[]>{
        if (this.mockEnabled) {
            let noticies$ = this.http.get(`assets/data/noticies.json`, this.getHeaders()).map(this.mapping.mapNoticiesResponse).catch(e => this.handleError(e));
            return noticies$;
        } else {
            let noticies$ = this.http.get(`${this.rootPath}/api/Noticies/get`, this.getHeadersWithOutToken())
                .map(this.mapping.mapNoticiesResponse);
            return noticies$;
        }
  }
/**
 * Metodo Rest Get Id 
 * @param id
 */
    get(id: string): Observable<Noticies> {
      let esdeveniments$ = this.http
          .get(`${this.rootPath}/api/Noticies/${id}`, this.getHeaders())
          .map(this.mapping.mapNoticiesResponse).catch(e => this.handleError(e)); 
      return esdeveniments$; 
  }

/**
 * Salvar cambios d'evento
 * @param esdeveniment
 */
    save(esdeveniment: Noticies) : Observable<Response>{ 
      return this.http
          .put(`${this.rootPath}/api/Noticies/${esdeveniment.Id}`, JSON.stringify(esdeveniment), this.getHeaders());
  }
 
}
 