﻿/**
    Author: Daniel Horta Vidal
    Licence: Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
**/
import { Injectable } from '@angular/core';

import { Events } from 'ionic-angular';
import { Storage } from '@ionic/storage';

import { Esdeveniment, Assistencia, Casteller, Noticies} from '../entities/entities'; 

import { UserInfo } from '../entities/UserInfo'; 
@Injectable()
export class StoreData { 
    /*Variables de Session Activa*/ 
    private _esdeveniments: Esdeveniment[] = [];
    private _castellers: Casteller[];
    private _noticies: Noticies[] = [];
    private _countNoticies: number = 0;
    private _token: String="";
    private _user: String="";
    private _userInfo: UserInfo= null;
    private _hasSeenTutorial: Boolean = true;
    private _dateActEsdeveniments: string = null; 
    private _dateActNoticies: string = null; 
    private _dateActCasteller: string = null; 

    /* PARAMETROS DE MEMORIA */
    private USER = 'username'; 
    private TOKEN = 'token';
    private USER_INFO = 'userInfo';
    private HAS_SEEN_TUTORIAL = 'hasSeenTutorial'; 
    private LIST_ESDEVENIMENTS = 'esdeveniments'; 
    private LIST_NOTICIES = 'noticies'; 
    private DATE_ACT_ESDEVENIMENTS = 'dataactesdeveniments'; 
    private DATE_ACT_NOTICIES = 'dataactnoticies';
    private DATE_ACT_CASTELLERS = 'dataactcastellers'; 

    private CASTELLERS = 'castellers'; 
    private load: number = 0;
     
    constructor(
        public events: Events,
        public storage: Storage
    ) {
       

    }
    public loadStore(): void {
        this.load = 0;
        console.info("Cargando variables en memoria");
        // 1
        this.storage.get(this.HAS_SEEN_TUTORIAL).then((value) => {
            this._hasSeenTutorial = value;
            this.isLoaded();
        }
        ).catch(e => { console.info("Error Carga HAS_SEEN_TUTORIAL:"); this.isLoaded(); });
        // 2
        this.storage.get(this.TOKEN).then(t => {
            this._token = t;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga TOKEN:"); this.isLoaded(); });
        // 3
        this.storage.get(this.USER).then((value) => {
            this._user = value;
            this.isLoaded();
        }
        ).catch(e => { console.info("Error Carga USER:"); this.isLoaded(); });
        // 4
        this.storage.get(this.USER_INFO).then((value) => {
            this._userInfo = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga USER_INFO:"); this.isLoaded(); });
        // 5
        this.storage.get(this.DATE_ACT_ESDEVENIMENTS).then((value) => {
            this._dateActEsdeveniments = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga DATA_ACTUALITZACIO:"); this.isLoaded(); });
        // 6
        this.storage.get(this.LIST_ESDEVENIMENTS).then((value) => {
            this._esdeveniments = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga ESDEVENIMENTS:"); this.isLoaded(); });

        // 7
        this.storage.get(this.LIST_NOTICIES).then((value) => {
            this._noticies = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga LIST_NOTICIES:"); this.isLoaded(); }); 

        // 8
        this.storage.get(this.DATE_ACT_NOTICIES).then((value) => {
            this._dateActNoticies = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga DATE_ACT_NOTICIES:"); this.isLoaded(); }); 

        // 9
        this.storage.get(this.CASTELLERS).then((value) => {
            this._castellers = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga CASTELLERS:"); this.isLoaded(); }); 
        //10 
        this.storage.get(this.DATE_ACT_CASTELLERS).then((value) => {
            this._dateActCasteller = value;
            this.isLoaded();
        }).catch(e => { console.info("Error Carga DATE_ACT_CASTELLERS:"); this.isLoaded(); }); 
    }
    private isLoaded(): void {
        this.load++;
        if (this.load == 9) {
            this.events.publish("store:load");
        }
          
    }
    shipTutorial(): Boolean {
        return this._hasSeenTutorial;
    };
    getSessionToken(): String {
        return this._token;
    }
    isCasteller(): boolean {
        if (!this._userInfo) return false;
        else if (this._userInfo.ConfirmCasteller){
            return true;
        } else 
        {
            return false;
        }
    }
    isJunta(): boolean {
        if (!this._userInfo) return false;
        else if (this._userInfo.Privilege === "JUNTA") {
            return true;
        } else {
            return false;
        }
    }
    
    getUsername(): String {
        return this._user;
    };
    getDataPubliEsdeveniments(): string {
        return this._dateActEsdeveniments;
    };
    getDataPubliNoticies(): string {
        return this._dateActNoticies;
    };
    getDataPubliCastellers(): string {
        return this._dateActCasteller;
    }
    clearNotification() :void {
        this._countNoticies = 0;
    }
    getUserSession(): UserInfo {
        return this._userInfo;
    }

    setAssistencia(assitencia: Assistencia[]): void {
        this._userInfo.Casteller.ConfirmPrecence = assitencia;
        
        this.setUserSession(this._userInfo);
         
    }
    setAcceptacions(castellers: Casteller[]) {
        this._userInfo.Casteller.AccepInvitations = castellers || [];
        this.setUserSession(this._userInfo);
    }
    setInvitations(castellers: Casteller[]) {
        this._userInfo.Casteller.Invitations = castellers || [];
        this.setUserSession(this._userInfo);
    }
    setDelegacioPropia(castellers: Casteller[]) {
        this._userInfo.Casteller.DelegacioPropia = castellers || []; 
        this.setUserSession(this._userInfo);
    }
    setAccepDelegacioPropia(castellers: Casteller[]) {
        this._userInfo.Casteller.DelegacioPropia = castellers || [];
        this.setUserSession(this._userInfo);
    }
    
    setUserSession(user: UserInfo) {
        this._userInfo = user; 
        this.storage.set(this.USER_INFO, user).then(t => console.info("Usuario actualizado")).catch(e => { console.info("Error Salvar USER_INFO:"); });
        if (this._userInfo.Casteller.ConfirmPrecence && this._esdeveniments) {
            this._userInfo.Casteller.ConfirmPrecence.forEach(ass => {
                this._esdeveniments.some(es => {
                    if (es.Id === ass.Esdeveniment.Id) {
                        es.Confirmat = true;
                        return true;
                    } else {
                        es.Confirmat = false;
                        return false;
                    }
                });
            }
            );
        }

    }
    public saveEsdeveniments(lstEsdeveniments: Esdeveniment[],dataPublicacio:String) :void {
        this._esdeveniments = lstEsdeveniments;
        
        this.storage.set(this.LIST_ESDEVENIMENTS, lstEsdeveniments); 
        this.storage.set(this.DATE_ACT_ESDEVENIMENTS, dataPublicacio); 
    } 
    public getEsdeveniments(): Esdeveniment[] {
        if (this._userInfo && this._userInfo.ConfirmCasteller && this._esdeveniments && this._userInfo.Casteller.ConfirmPrecence) {
            this._esdeveniments.forEach(es => {
                es.Confirmat = false;
                this._userInfo.Casteller.ConfirmPrecence.forEach(es1 => {
                    if (es.Id === es1.Esdeveniment.Id) es.Confirmat = true;
                });
            });
        }
        
        return this._esdeveniments;
    }
    public getCastellers(): Casteller[] {
        return this._castellers;
    }
    public setCastellers(castellers: Casteller[], date: string) {
        if (!this._castellers) {
            this._castellers = castellers;
            this.storage.set(this.CASTELLERS, this._castellers);
            this.storage.set(this.DATE_ACT_CASTELLERS, date);
        }else if (castellers) {
             castellers.forEach(cas => {
                let i: number = 0;
                for (i = 0; i < this._castellers.length; i++) {
                    if (cas.Id === this._castellers[i].Id) {
                        this._castellers[i] = cas ;
                        break;
                    }
                }
                if (i >= this._castellers.length) {
                    this._castellers.push(cas);
                }
            });
             this.storage.set(this.CASTELLERS, this._castellers);
             this.storage.set(this.DATE_ACT_CASTELLERS, date);
        }
        
    }

    public saveNoticies(lstNoticies: Noticies[] , datePublicacio:String): void {
        this._countNoticies = 0;
        if (!lstNoticies) return;
        if (this._noticies) {
            lstNoticies.forEach(it => {
                var not = this._noticies.find(it1 => it1.Id === it.Id);
                if (!not) this._countNoticies++;
            });
        } else {
            this._countNoticies = lstNoticies.length;
        }
        this._noticies = lstNoticies;
        this.storage.set(this.LIST_NOTICIES, lstNoticies);
        this.storage.set(this.DATE_ACT_NOTICIES, datePublicacio);

        this.events.publish("push:noticies");
        console.log("Enviada notificacion Noticies");
    }
    public getNotificationNoticies(): number {
        return this._countNoticies;
    }
    public getNoticies(): Noticies[] {
        return this._noticies;
    } 
    /**
     * Persiste la informacion del usuario en el dispositivo
 
     * @param userName
     * @param password
     * @param token
     */
    login(userName: String, token : String ): void {  
        this.storage.set(this.USER, userName); 
        this.storage.set(this.TOKEN, token);
        this._token = token;
        this._user = userName;
        this.events.publish("user:login"); 
    }
   /**
    * Funcion de logout para borrar toda la informacion relacionda con la session del usuario
    */
    logout(): void {
        this.clearMovil();
        this.events.publish("user:logout");
    }
    clearUser(): void {
        this._user = null;
        this.storage.set(this.USER_INFO, null);
        this._userInfo = null;
        this.storage.set(this.TOKEN, null);
        this._token = null;
    }
    clearMovil():void {
        this.storage.set(this.USER, null);
        this._user = null; 
        this.storage.set(this.USER_INFO, null);
        this._userInfo = null;
        this.storage.set(this.TOKEN, null);
        this._token = null;
        this.storage.set(this.CASTELLERS, null);
        this._castellers = null;
        this.storage.set(this.DATE_ACT_CASTELLERS, null);
        this._dateActCasteller = null;
        this.storage.set(this.DATE_ACT_ESDEVENIMENTS, null);
        this._dateActEsdeveniments = null;
        this.storage.set(this.DATE_ACT_NOTICIES, null);
        this._dateActNoticies = null;
        this.storage.set(this.LIST_NOTICIES, null);
        this.storage.set(this.LIST_ESDEVENIMENTS, null);
        this._esdeveniments = null;

    }
    
}