﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Microsoft.AspNet.Identity;
using System.Web.Http;
using System.Web.Http.Cors;
using System.Web;
using System.Net.Http;
using System.ServiceModel.Channels;
/// <summary>
/// Aplicació de Gestió Castellera
/// </summary>
/// <copyright>
/// Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
/// </copyright>
/// <author>
/// Daniel Horta Vidal
/// </author>
/// 
namespace AppinyaServer.Controllers
{
     
    /**
     * Abstraccion de la capa de servicios
     */
    public class ApiControllerExtension : ApiController
    {
        #region Attributes;
        protected const string ROL_ADMINISTRATOR = "ADMIN";
        protected const string ROL_JUNTA = "JUNTA";
        protected const string ROL_INVITAT = "Usuari";

      
        #endregion;

        /*
         * Obtiene el nombre de la session
         */
        protected String GetUserName ()
        {
            var userName = this.RequestContext.Principal.Identity.Name; 
            return userName ;
        }
        protected Boolean isRoleJunta()
        {
            return this.RequestContext.Principal.IsInRole(ROL_JUNTA); 
        }
        protected Boolean isRoleAdmin()
        {
            return this.RequestContext.Principal.IsInRole(ROL_ADMINISTRATOR);
        }
        /*
         * Obtiene la IP del cliente (para futuros ataques amaters) ;) 
         */
        protected string GetClientIp()
        {

            if (Request.Properties.ContainsKey("MS_HttpContext"))
            {
                return ((HttpContextWrapper)Request.Properties["MS_HttpContext"]).Request.UserHostAddress;
            }
            else if (Request.Properties.ContainsKey(RemoteEndpointMessageProperty.Name))
            {
                RemoteEndpointMessageProperty prop = (RemoteEndpointMessageProperty)Request.Properties[RemoteEndpointMessageProperty.Name];
                return prop.Address;
            }
            else if (HttpContext.Current != null)
            {
                return HttpContext.Current.Request.UserHostAddress;
            }
            else
            {
                return null;
            }
        }
        /**
         * Obtiene la URL de la peticion del cliente (solo la base comun Ej. http://localhost/Appinya (sin el resto) 
         */
        protected string GetCurrentURLServer()
        {
            int cont = Request.RequestUri.AbsoluteUri.IndexOf("/api/");
            if (cont ==-1 ) cont = Request.RequestUri.AbsoluteUri.IndexOf("/Api/");
            return Request.RequestUri.AbsoluteUri.Substring(0, cont);
        }
        
        
        /**
         * Establece la forma estandard de enviar errores entre el aplicativo i la capa cliente 
         */
        protected IHttpActionResult GetErrorResult(IdentityResult result)
        {
            if (result == null)
            {
                return InternalServerError();
            }

            if (!result.Succeeded)
            {
                if (result.Errors != null)
                {
                    foreach (string error in result.Errors)
                    {
                        
                        ModelState.AddModelError("errors", error);
                    }
                }

                if (ModelState.IsValid)
                {
                    // No ModelState errors are available to send, so just return an empty BadRequest.
                    return BadRequest();
                }

                return BadRequest(ModelState);
            }

            return null;
        }
    }
    
}
