﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net; 
using System.Web.Http;
using AppinyaLib.Api.Entities;
using AppinyaLib.Database;
using AppinyaServer.Models;
using AppinyaLib.Segurity;
using System.Web; 
using System.ServiceModel.Channels;
using System.Net.Http.Headers;
using System.Net.Http; 
using System.Threading.Tasks;
using Microsoft.AspNet.Identity;
using Microsoft.AspNet.Identity.EntityFramework;
using Microsoft.AspNet.Identity.Owin;
using AppinyaLib.Comunication;
using System.Configuration;
using System.Diagnostics;
using log4net;
using AppinyaLib.BS;
/// <summary>
/// Aplicació de Gestió Castellera
/// </summary>
/// <copyright>
/// Reconocimiento-NoComercial 3.0 España (CC BY-NC 3.0 ES)
/// </copyright>
/// <author>
/// Daniel Horta Vidal
/// </author>
namespace AppinyaServer.Controllers
{
    /// <summary>
    /// Clase de gestion de funciones del Usuario de la aplicacion 
    /// </summary> 
    [Authorize]
    [RoutePrefix("api/User")]
    public class UserController : ApiControllerExtension
    {
        #region Attributes;  
        private static readonly log4net.ILog log = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
        private ApplicationUserManager _userManager; 
        public ApplicationUserManager UserManager
        {
            get
            {
                return _userManager ?? Request.GetOwinContext().GetUserManager<ApplicationUserManager>();
            }
            private set
            {
                _userManager = value;
            }
        }
        #endregion;
       
        /**
         * GET api/Use Recoge la informacion del usuario
         */
        [Route("getUserInfo")]
        public UserInfo GetUserInfo()
        {
            String userName = GetUserName();
            if (userName == null) return null;
            log.Debug("Get Informacion Usuario: " + userName);
            return UsuariBs.getUserInfo(userName);
           
        }
        /**
         *  GET api/User/sendMailConfirmation Envia mensaje de confirmacion;
         */
        [HttpGet]
        [Route("sendMailConfirmation")]
        public void SendMailConfirmation ()
        {
            try {  
            String userName = GetUserName();
            if (userName == null) return;
            log.Info("Enviado un correo: " + userName);
            String template = System.Web.Hosting.HostingEnvironment.MapPath("~/Resources/MailTemplates/templateToken.html");  
            SegurityBs.SendEmailConfirmation(userName, GetClientIp(), GetCurrentURLServer(), template);
                System.Diagnostics.Trace.WriteLine("Se envia el correu ");
            }
            catch (Exception e) { log.Error("Error enviado un correo: " + e.Message);  }
        }

        /**
         *  GET api/User/mailConfirmation - Link del correo de confirmacion
         */
        [AllowAnonymous]
        [HttpGet]
        [Route("mailConfirmation")]
        public HttpResponseMessage MailConfirmation(String token, String userName)
        {
              
            var response = Request.CreateResponse(HttpStatusCode.Redirect);
            if (SegurityBs.ConfirmationEmail(userName, token)) {
                log.Info("Correo: confirmado: " + userName);
                response.Headers.Location = new Uri(GetCurrentURLServer() + "/Resources/MailMessages/ConfirmacionCorreo.html");
                return response;
            }else
            {
                response.Headers.Location = new Uri(GetCurrentURLServer() + "/Resources/MailMessages/ErrorCorreo.html");
                return response;
            }
            
        }
        /**
         * POST api/User/sendMailSupport - Envia un correo a soporte con el incidente 
         */
        [AllowAnonymous]
        [HttpPost]
        [Route("sendMailSupport")]
        public void SendMailSupport([FromBody] String message)
        {
            try
            {
                var userName = GetUserName();
                String template = System.Web.Hosting.HostingEnvironment.MapPath("~/Resources/MailTemplates/templateSupport.html");
                Dictionary<String, String> parames = new Dictionary<String, String>();
                parames.Add("userName", userName);
                parames.Add("message", message);
                log.Info("Correo se envia correo de soporte : " + userName);
                SendMail.SendEmailWithHtmlTemplate("Support Email", ConfigurationManager.AppSettings["mail-support"], template, parames);
            }
            catch (Exception e) { log.Error("Error enviado un correo: " + e.Message); }
        }
        [AllowAnonymous]
        [HttpGet]
        [Route("oblidarConstrasenya")]
        public void oblidarConstrasenya([FromBody] String user)
        {
            try
            {
                
            }
            catch (Exception e) { log.Error("Error enviado un correo: " + e.Message); }
        }
        // POST api/Account/ChangePassword
        [Route("changePassword")]
        public async Task<IHttpActionResult> ChangePassword(ChangePasswordBindingModel model)
        {
            String userName = GetUserName();
            ApplicationUser user = UserManager.FindByEmail(userName);

            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            IdentityResult result = await UserManager.ChangePasswordAsync(user.Id, model.OldPassword,
                model.NewPassword);

            if (!result.Succeeded)
            {
                log.Info("Error en el canvi de passwordr:" + userName);
                return GetErrorResult(result);
            }
            log.Debug("Canvi de passwordr:" + userName);
            return Ok();
        }
        /*
         * POST api/Account/Register  - Funcion de Alta del usuario
         */
        [AllowAnonymous]
        [Route("registerUser")]
        public IHttpActionResult Register(RegisterBindingModel model)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            var user = new ApplicationUser() { UserName = model.Email, Email = model.Email  };
          
            IdentityResult result = UserManager.Create(user, model.Password);

            if (!result.Succeeded)
            {
                log.Info("Error en el Registre del usuari :" + model.Email);
                return GetErrorResult(result);
            }
            else
            {
                using (castellersEntities db = new castellersEntities())
                {
                    AspNetUsers usr = db.AspNetUsers.Where(t => t.Email == model.Email).FirstOrDefault();
                    usr.LastName = model.LastName;
                    usr.Name = model.Name;
                    db.SaveChanges();
                }
                log.Info("Registre Nou del usuari :" + model.Email);
                SendMailConfirmation();
            }

            return Ok();
        }



    }
}
